searchData={"content_type":"text/markdown","items":[{"doc":"Module responsible for starting the Francis server and to wrap the Plug functionality\n\nThis module performs multiple tasks:\n  * Uses the Application module to start the Francis server\n  * Defines the Francis.Router which uses Francis.Plug.Router, :match and :dispatch\n  * Defines the macros get, post, put, delete, patch and ws to define routes for each operation\n  * Setups Plug.Static with the given options\n  * Sets up Plug.Parsers with the default configuration of:\n    * ```elixir\n      plug(Plug.Parsers,\n        parsers: [:urlencoded, :multipart, :json],\n        json_decoder: Jason\n      )\n      ```\n\nYou can also set the following options:\n  * :bandit_opts - Options to be passed to Bandit\n  * :plugs - List of plugs to be used by Francis\n  * :static - Configure Plug.Static to serve static files\n  * :parser - Overrides the default configuration for Plug.Parsers","ref":"Francis.html","title":"Francis","type":"module"},{"doc":"Defines a DELETE route","ref":"Francis.html#delete/2","title":"Francis.delete/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  delete \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#delete/2-examples","title":"Examples - Francis.delete/2","type":"macro"},{"doc":"Defines a GET route","ref":"Francis.html#get/2","title":"Francis.get/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  get \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#get/2-examples","title":"Examples - Francis.get/2","type":"macro"},{"doc":"Defines a PATCH route","ref":"Francis.html#patch/2","title":"Francis.patch/2","type":"macro"},{"doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  patch \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#patch/2-examples","title":"Examples - Francis.patch/2","type":"macro"},{"doc":"Defines a POST route","ref":"Francis.html#post/2","title":"Francis.post/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  post \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#post/2-examples","title":"Examples - Francis.post/2","type":"macro"},{"doc":"Defines a PUT route","ref":"Francis.html#put/2","title":"Francis.put/2","type":"macro"},{"doc":"```\ndefmodule Example.Router do\n  use Francis\n\n  put \"/hello\", fn conn ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#put/2-examples","title":"Examples - Francis.put/2","type":"macro"},{"doc":"Defines an action for umatched routes and returns 404","ref":"Francis.html#unmatched/1","title":"Francis.unmatched/1","type":"macro"},{"doc":"Defines a WebSocket route that sends text type responses.\n\nThe handler function receives the message and the socket state, and it can return a binary or a map.\nThe state includes:\n- `:transport` - The transport process that can be used to send messages back to the client using `send/2`\n- `:id` - A unique identifier for the WebSocket connection that can be used to track the connection\n- `:path` - The path of the WebSocket connection to identify the route that triggered the connection","ref":"Francis.html#ws/3","title":"Francis.ws/3","type":"macro"},{"doc":"```elixir\ndefmodule Example.Router do\n  use Francis\n\n  ws \"/hello\", fn _, socket ->\n    \"Hello World!\"\n  end\nend\n```","ref":"Francis.html#ws/3-examples","title":"Examples - Francis.ws/3","type":"macro"},{"doc":"Module that imports required macros from Francis and Plug.Router","ref":"Francis.Plug.Router.html","title":"Francis.Plug.Router","type":"module"},{"doc":"Watcher mode for development that checks modified time of your files and recompiles them","ref":"Francis.Watcher.html","title":"Francis.Watcher","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Francis.Watcher.html#child_spec/1","title":"Francis.Watcher.child_spec/1","type":"function"},{"doc":"Callback implementation for  GenServer.init/1 .","ref":"Francis.Watcher.html#init/1","title":"Francis.Watcher.init/1","type":"function"},{"doc":"","ref":"Francis.Watcher.html#start_link/1","title":"Francis.Watcher.start_link/1","type":"function"},{"doc":"Generates a new Francis project.\nThis task creates a new directory with the specified application name and a basic project structure.","ref":"Mix.Tasks.Francis.New.html","title":"mix francis.new","type":"task"},{"doc":"mix francis.new   [--sup [ ]]","ref":"Mix.Tasks.Francis.New.html#module-usage","title":"Usage - mix francis.new","type":"task"},{"doc":"mix francis.new my_app\n    mix francis.new my_app --sup\n    mix francis.new my_app --sup MyApp","ref":"Mix.Tasks.Francis.New.html#module-examples","title":"Examples - mix francis.new","type":"task"},{"doc":"","ref":"Mix.Tasks.Francis.New.html#main/1","title":"Mix.Tasks.Francis.New.main/1","type":"function"},{"doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.Francis.New.html#run/1","title":"Mix.Tasks.Francis.New.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Francis.New.html#usage/0","title":"Mix.Tasks.Francis.New.usage/0","type":"function"},{"doc":"Generates Docker deployment files for Francis projects.\n\nThis task creates a `Dockerfile` and `.dockerignore` in the current working directory,\nusing the project name and configuration. It is intended to simplify containerization\nand deployment of Francis-based applications.","ref":"Mix.Tasks.Francis.Release.html","title":"mix francis.release","type":"task"},{"doc":"mix francis.release [OPTIONS]","ref":"Mix.Tasks.Francis.Release.html#module-usage","title":"Usage - mix francis.release","type":"task"},{"doc":"* `-p`, `--port  ` - Port to expose in the Docker container (default: 4000).\n  * `--elixir-version  ` - Elixir version to use in the Docker image (default: 1.18.4).\n  * `--otp-version  ` - Erlang/OTP version to use in the Docker image (default: 27.3.4).\n\nExample:\n\n    mix francis.release --port 8080 --elixir-version 1.16.2 --otp-version 26.2.1\n\nThis will generate a Dockerfile exposing port 8080 and using the specified\nElixir and OTP versions. If you use some combination of versions that are not\ncompatible it will fail when building the docker image.\n\nAll files are generated in the current working directory. Unknown options are ignored.","ref":"Mix.Tasks.Francis.Release.html#module-command-line-options","title":"Command line options - mix francis.release","type":"task"},{"doc":"","ref":"Mix.Tasks.Francis.Release.html#c:generate_files/1","title":"Mix.Tasks.Francis.Release.generate_files/1","type":"callback"},{"doc":"Starts the application by configuring all endpoints servers to run.\n\nNote: to start the endpoint without using this mix task you must set\n`server: true` in your `Phoenix.Endpoint` configuration.","ref":"Mix.Tasks.Francis.Server.html","title":"mix francis.server","type":"task"},{"doc":"Task accepts the same command-line options as `mix run`.\n\nThe `--no-halt` flag is automatically added.","ref":"Mix.Tasks.Francis.Server.html#module-command-line-options","title":"Command line options - mix francis.server","type":"task"},{"doc":"# Francis\n\n[![Hex version badge](https://img.shields.io/hexpm/v/francis.svg)](https://hex.pm/packages/francis)\n[![License badge](https://img.shields.io/hexpm/l/repo_example.svg)](https://github.com/filipecabaco/francis/blob/master/LICENSE.md)\n[![Elixir CI](https://github.com/filipecabaco/francis/actions/workflows/elixir.yaml/badge.svg)](https://github.com/filipecabaco/francis/actions/workflows/elixir.yaml)\n\nSimple boilerplate killer using Plug and Bandit inspired by [Sinatra](https://sinatrarb.com) for Ruby.\n\nFocused on reducing time to build as it offers automatic request parsing, automatic response parsing, easy DSL to build quickly new endpoints and websocket listeners.","ref":"readme.html","title":"Francis","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed by adding `francis` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:francis, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Francis","type":"extras"},{"doc":"To start the server up you can run `mix francis.server` or if you need a iex console you can run with `iex -S mix francis.server`.\n\nTo create the Dockerfile that can be used for deployment you can run:\n\n```bash\nmix francis.release\n```","ref":"readme.html#usage","title":"Usage - Francis","type":"extras"},{"doc":"If you want to have a watcher that will reload the server when you change your code:\n\n```elixir\nimport Config\n\nconfig :francis, watcher: true\n```\n\nIt defaults to `false`","ref":"readme.html#watcher","title":"Watcher - Francis","type":"extras"},{"doc":"```elixir\ndefmodule Example do\n  use Francis\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n  post(\"/\", fn conn -> conn.body_params end)\n\n  ws(\"ws\", fn \"ping\" -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```\n\nAnd in your `mix.exs` file add that this module should be the one used for\nstartup:\n\n```elixir\ndef application do\n   [\n     extra_applications: [:logger],\n     mod: {Example, []}\n   ]\n end\n```\n\nThis will ensure that Mix knows what module should be the entrypoint.","ref":"readme.html#example-of-a-router","title":"Example of a router - Francis","type":"extras"},{"doc":"With the `static` option, you are able to setup the options for `Plug.Static` to serve static assets easily.\n\n```elixir\ndefmodule Example do\n  use Francis, static: [from: \"pric/static\", to: \"/\"]\nend\n```","ref":"readme.html#example-of-a-router-with-static-serving","title":"Example of a router with Static serving - Francis","type":"extras"},{"doc":"With the `plugs` option you are able to apply a list of plugs that happen\nbetween before dispatching the request.\n\nIn the following example we're adding the `Plug.BasicAuth` plug to setup basic\nauthentication on all routes\n\n```elixir\ndefmodule Example do\n  import Plug.BasicAuth\n\n  use Francis, plugs: [{:basic_auth, username: \"test\", password: \"test\"}]\n\n  get(\"/\", fn _ -> \" world \" end)\n  get(\"/:name\", fn %{params: %{\"name\" => name}} -> \"hello #{name}\" end)\n\n  ws(\"ws\", fn \"ping\", _socket -> \"pong\" end)\n\n  unmatched(fn _ -> \"not found\" end)\nend\n```\n\nCheck the folder [example](https://github.com/filipecabaco/francis/tree/main/example) to check the code.","ref":"readme.html#example-of-a-router-with-plugs","title":"Example of a router with Plugs - Francis","type":"extras"}],"producer":{"name":"ex_doc","version":"0.38.1"},"proglang":"elixir"}